@@ -13,13 +13,11 @@
 ##############################################################################
 """Session implementation using cookies
 
-$Id: http.py 116073 2010-09-01 10:39:46Z menesis $
 """
 
 # BBB
-from zope.session.http import (ICookieClientIdManager,
-                               MissingClientIdException,
-                               notifyVirtualHostChanged,
-                               CookieClientIdManager,
-                               digestEncode,
-                               cookieSafeTrans)
+from zope.session.http import CookieClientIdManager
+from zope.session.http import ICookieClientIdManager
+from zope.session.http import MissingClientIdException
+from zope.session.http import digestEncode
+from zope.session.http import notifyVirtualHostChanged
