@@ -13,13 +13,12 @@
 ##############################################################################
 """Interfaces for session utility.
 
-$Id: interfaces.py 116073 2010-09-01 10:39:46Z menesis $
 """
 
 # BBB
-from zope.session.interfaces import (IClientIdManager,
-                                     IClientId,
-                                     ISessionDataContainer,
-                                     ISession,
-                                     ISessionData,
-                                     ISessionPkgData)
+from zope.session.interfaces import IClientId
+from zope.session.interfaces import IClientIdManager
+from zope.session.interfaces import ISession
+from zope.session.interfaces import ISessionData
+from zope.session.interfaces import ISessionDataContainer
+from zope.session.interfaces import ISessionPkgData
