@@ -13,15 +13,13 @@
 ##############################################################################
 """Session implementation
 
-$Id: session.py 116073 2010-09-01 10:39:46Z menesis $
 """
 
 # BBB
-from zope.session.session import (SessionData,
-                                  SessionPkgData,
-                                  Session,
-                                  RAMSessionDataContainer,
-                                  PersistentSessionDataContainer,
-                                  ClientId,
-                                  digestEncode,
-                                  cookieSafeTrans)
+from zope.session.session import ClientId
+from zope.session.session import PersistentSessionDataContainer
+from zope.session.session import RAMSessionDataContainer
+from zope.session.session import Session
+from zope.session.session import SessionData
+from zope.session.session import SessionPkgData
+from zope.session.session import digestEncode
